class Axes:
    limmits = None
    ticks = None
    labels = None

    def __init__(self, limits=None, ticks=None, labels=None):
        self.limmits = limits
        self.ticks = ticks
        self.labels = labels
